summaryrefslogtreecommitdiff
path: root/wct4xxp.c
diff options
context:
space:
mode:
authormarkster <markster@5390a7c7-147a-4af0-8ec9-7488f05a26cb>2003-07-15 19:58:39 +0000
committermarkster <markster@5390a7c7-147a-4af0-8ec9-7488f05a26cb>2003-07-15 19:58:39 +0000
commit4d464bb861ef5d8896cffea1004775882c14a306 (patch)
treec5b6be519b0e70506e04624b69021bd36e4e7d26 /wct4xxp.c
parenta5cec4a272d18d920209d80f38359ff7a8b022f3 (diff)
Minor cleanups
git-svn-id: http://svn.digium.com/svn/zaptel/trunk@213 5390a7c7-147a-4af0-8ec9-7488f05a26cb
Diffstat (limited to 'wct4xxp.c')
-rwxr-xr-xwct4xxp.c9
1 files changed, 3 insertions, 6 deletions
diff --git a/wct4xxp.c b/wct4xxp.c
index f1d275b..6b68c27 100755
--- a/wct4xxp.c
+++ b/wct4xxp.c
@@ -83,8 +83,6 @@ struct t4 {
int num; /* Which card we are */
int t1e1; /* T1/E1 select pins */
int globalconfig; /* Whether global setup has been done */
- int last; /* XXX DEBUG area XXX */
- int olast; /* XXX DEBUG area XXX */
int syncsrc; /* active sync source */
int syncs[4]; /* sync sources */
int psyncs[4]; /* span-relative sync sources */
@@ -93,7 +91,6 @@ struct t4 {
#ifdef FANCY_ALARM
int alarmpos;
#endif
- char *type; /* Type of tormenta 2 card */
int irq; /* IRQ used by device */
int order; /* Order */
int flags; /* Device flags */
@@ -125,7 +122,7 @@ struct t4 {
int taskletpending;
int taskletexec;
int txerrors;
- struct tasklet_struct tor2_tlet;
+ struct tasklet_struct t4xxp_tlet;
#endif
int spantype[4]; /* card type, T1 or E1 */
unsigned int passno; /* number of interrupt passes */
@@ -816,8 +813,8 @@ static int t4_findsync(struct t4 *wc)
int p;
int nonzero;
int newsyncsrc = 0; /* Zaptel span number */
- int newsyncnum = 0; /* tor2 card number */
- int newsyncspan = 0; /* span on given tor2 card */
+ int newsyncnum = 0; /* t4xxp card number */
+ int newsyncspan = 0; /* span on given t4xxp card */
spin_lock_irqsave(&synclock, flags);
#if 1
if (!wc->num) {